@@ -1,7 +1,7 @@
 // synthv1widget_wave.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 #include "synthv1_wave.h"
 
 #include <QPainter>
+#include <QPainterPath>
 #include <QMouseEvent>
 #include <QWheelEvent>
 
@@ -41,9 +42,8 @@ inline float safe_value ( float x )
 // synthv1widget_wave -- Custom widget
 
 // Constructor.
-synthv1widget_wave::synthv1widget_wave (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QFrame(pParent, wflags),
+synthv1widget_wave::synthv1widget_wave ( QWidget *pParent )
+	: QFrame(pParent),
 		m_bDragging(false), m_iDragShape(0)
 {
 	m_pWave = new synthv1_wave_lf(128);
@@ -220,7 +220,7 @@ void synthv1widget_wave::mouseDoubleClickEvent ( QMouseEvent *pMouseEvent )
 
 void synthv1widget_wave::wheelEvent ( QWheelEvent *pWheelEvent )
 {
-	const int delta = (pWheelEvent->delta() / 60);
+	const int delta = (pWheelEvent->angleDelta().y() / 60);
 
 	if (pWheelEvent->modifiers() & (Qt::ShiftModifier | Qt::ControlModifier)) {
 		setWaveShape(waveShape() + (delta < 0 ? -1 : +1));
